==> bow-ui-0.5-sources.jar: org/chorem/bow/AliasServlet.java <==
/*
 * #%L
 * bow
 * 
 * $Id: AliasServlet.java 242 2011-04-19 06:36:19Z kmorin $
 * $HeadURL: http://svn.chorem.org/svn/bow/tags/bow-0.5/bow-ui/src/main/java/org/chorem/bow/AliasServlet.java $
 * %%
 * Copyright (C) 2010 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.chorem.bow;

import org.apache.commons.lang.StringUtils;
import org.nuiton.wikitty.WikittyProxy;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;

/**
 * TODO poussin 20110216 a revoir avec le ticket http://www.chorem.org/issues/show/295
 *
 * @author bbrossaud
 * @deprecated transformed to struts action since 0.5
 */
@Deprecated
public class AliasServlet extends HttpServlet {

	private static final long serialVersionUID = 1L;
	protected String bowServletUrl = "";

    public AliasServlet() {
        BowConfig config = BowConfig.getInstance();
        bowServletUrl = config.getBowUrl() + config.getServletBow() ;
    }

    @Override
    public void doGet(HttpServletRequest request, HttpServletResponse response)
            throws IOException, ServletException {
        doPost(request, response);
    }

    /* @param request              servlet request
     * @param response             servlet response
     * @throws ServletException    if a servlet error occurs
     */
    @Override
    public void doPost(HttpServletRequest request, HttpServletResponse response)
            throws IOException, ServletException {
        try {
            String alias = request.getPathInfo();
            if (!StringUtils.isEmpty(alias)) {
                // remove first '/'
                alias = alias.substring(1);
                BowSession session = BowSession.getBowSession(request);
                WikittyProxy proxy = session.getProxy();
                
                /*Criteria criteria = Search.query().eq(
                        BowAlias.FQ_FIELD_BOWALIAS_ALIAS, alias).criteria();
                
                BowAlias bowAlias = proxy.findByCriteria(BowAlias.class, criteria);
                String bookmarkId;
                if (bowAlias == null) {
                    bookmarkId = alias;
                } else {
                    bookmarkId = bowAlias.getBowBookmark();                    
                }
                BowBookmark bookmark = proxy.restore(BowBookmark.class, bookmarkId);
                if (bookmark != null) {
                    String redirect = bookmark.getLink();
                    int clicks = bookmark.getClick() + 1;
                    bookmark.setClick(clicks);
                    proxy.store(bookmark);
                    response.sendRedirect(redirect);
                } else {
                    response.sendRedirect(bowServletUrl);
                }*/
            } else {
                response.sendRedirect(bowServletUrl);
            }
        } catch (Exception eee) {
            request.getRequestDispatcher("error.jsp").forward(request, response);
        }
    }
}

==> bow-ui-1.0-sources.jar: org/chorem/bow/AliasServlet.java <==
/*
 * #%L
 * bow
 * 
 * $Id: AliasServlet.java 285 2011-05-16 13:21:52Z sletellier $
 * $HeadURL: http://svn.chorem.org/svn/bow/tags/bow-1.0/bow-ui/src/main/java/org/chorem/bow/AliasServlet.java $
 * %%
 * Copyright (C) 2010 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.chorem.bow;

import org.apache.commons.lang.StringUtils;
import org.nuiton.wikitty.WikittyProxy;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;

/**
 * TODO poussin 20110216 a revoir avec le ticket http://www.chorem.org/issues/show/295
 *
 * @author bbrossaud
 * @deprecated transformed to struts action since 0.5
 */
@Deprecated
public class AliasServlet extends HttpServlet {

	private static final long serialVersionUID = 1L;
	protected String bowServletUrl = "";

    public AliasServlet() {
        bowServletUrl = BowConfig.getBowUrl() + BowConfig.getServletBow();
    }

    @Override
    public void doGet(HttpServletRequest request, HttpServletResponse response)
            throws IOException, ServletException {
        doPost(request, response);
    }

    /* @param request              servlet request
     * @param response             servlet response
     * @throws ServletException    if a servlet error occurs
     */
    @Override
    public void doPost(HttpServletRequest request, HttpServletResponse response)
            throws IOException, ServletException {
        try {
            String alias = request.getPathInfo();
            if (!StringUtils.isEmpty(alias)) {
                // remove first '/'
                alias = alias.substring(1);
                BowSession session = BowSession.getBowSession(request);
                WikittyProxy proxy = session.getProxy();
                
                /*Criteria criteria = Search.query().eq(
                        BowAlias.FQ_FIELD_BOWALIAS_ALIAS, alias).criteria();
                
                BowAlias bowAlias = proxy.findByCriteria(BowAlias.class, criteria);
                String bookmarkId;
                if (bowAlias == null) {
                    bookmarkId = alias;
                } else {
                    bookmarkId = bowAlias.getBowBookmark();                    
                }
                BowBookmark bookmark = proxy.restore(BowBookmark.class, bookmarkId);
                if (bookmark != null) {
                    String redirect = bookmark.getLink();
                    int clicks = bookmark.getClick() + 1;
                    bookmark.setClick(clicks);
                    proxy.store(bookmark);
                    response.sendRedirect(redirect);
                } else {
                    response.sendRedirect(bowServletUrl);
                }*/
            } else {
                response.sendRedirect(bowServletUrl);
            }
        } catch (Exception eee) {
            request.getRequestDispatcher("error.jsp").forward(request, response);
        }
    }
}
